Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(499)

Unified Diff: test/mjsunit/function-arguments-null.js

Issue 1072573002: [es6] ship @@toStringTag (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Fix prototype-ordinary-objects test Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: test/mjsunit/function-arguments-null.js
diff --git a/test/mjsunit/function-arguments-null.js b/test/mjsunit/function-arguments-null.js
index 21e542fc81e7a93362a886810ad7076443efecc5..6b47a10188b8ab2a97bca2d1731dec4241523eaa 100644
--- a/test/mjsunit/function-arguments-null.js
+++ b/test/mjsunit/function-arguments-null.js
@@ -25,6 +25,9 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// The arguments property of functions should be null when not
// executing inside the function.
-assertTrue(toString.arguments === null);
+
+function sloppy() {}
+
+assertTrue(sloppy.arguments === null);

Powered by Google App Engine
This is Rietveld 408576698
@@ -25,6 +25,9 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-// The arguments property of functions should be null when not
+// The arguments property of sloppy functions should be null when not
// executing inside the function.